==> blanco.plugin.jsf_0.0.4-src.zip: src/blanco/jsf/valueobject/BlancoJsfStructure.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2009 IGA Tosiki
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.jsf.valueobject;

import java.util.List;

/**
 * blancoJsf ob`NX̊e킵܂B
 */
public class BlancoJsfStructure {
    /**
     * JSFIDw肵܂BK{ڂłB
     *
     * tB[h: [name]B
     */
    private String fName;

    /**
     * pbP[Ww肵܂BK{ڂłB
     *
     * tB[h: [package]B
     */
    private String fPackage;

    /**
     * bZ[W`̐Lڂ܂B
     *
     * tB[h: [description]B
     */
    private String fDescription;

    /**
     * NX̌ɕt^TtBbNXB
     *
     * tB[h: [suffix]B
     */
    private String fSuffix;

    /**
     * ʃtH[h̗LB
     *
     * tB[h: [forward]B
     * ftHg: [false]B
     */
    private boolean fForward = false;

    /**
     * beanꗗ̃XgB
     *
     * tB[h: [beanList]B
     * ftHg: [new java.util.ArrayList<blanco.jsf.valueobject.BlancoJsfBeanItemStructure>()]B
     */
    private List<blanco.jsf.valueobject.BlancoJsfBeanItemStructure> fBeanList = new java.util.ArrayList<blanco.jsf.valueobject.BlancoJsfBeanItemStructure>();

    /**
     * SQL`IDꗗ̃XgB
     *
     * tB[h: [sqlList]B
     * ftHg: [new java.util.ArrayList<blanco.jsf.valueobject.BlancoJsfSqlItemStructure>();]B
     */
    private List<blanco.jsf.valueobject.BlancoJsfSqlItemStructure> fSqlList = new java.util.ArrayList<blanco.jsf.valueobject.BlancoJsfSqlItemStructure>();;

    /**
     * tB[h [name] ̒lݒ肵܂B
     *
     * tB[h̐: [JSFIDw肵܂BK{ڂłB]B
     *
     * @param argName tB[h[name]ɐݒ肷lB
     */
    public void setName(final String argName) {
        fName = argName;
    }

    /**
     * tB[h [name] ̒l擾܂B
     *
     * tB[h̐: [JSFIDw肵܂BK{ڂłB]B
     *
     * @return tB[h[name]擾lB
     */
    public String getName() {
        return fName;
    }

    /**
     * tB[h [package] ̒lݒ肵܂B
     *
     * tB[h̐: [pbP[Ww肵܂BK{ڂłB]B
     *
     * @param argPackage tB[h[package]ɐݒ肷lB
     */
    public void setPackage(final String argPackage) {
        fPackage = argPackage;
    }

    /**
     * tB[h [package] ̒l擾܂B
     *
     * tB[h̐: [pbP[Ww肵܂BK{ڂłB]B
     *
     * @return tB[h[package]擾lB
     */
    public String getPackage() {
        return fPackage;
    }

    /**
     * tB[h [description] ̒lݒ肵܂B
     *
     * tB[h̐: [bZ[W`̐Lڂ܂B]B
     *
     * @param argDescription tB[h[description]ɐݒ肷lB
     */
    public void setDescription(final String argDescription) {
        fDescription = argDescription;
    }

    /**
     * tB[h [description] ̒l擾܂B
     *
     * tB[h̐: [bZ[W`̐Lڂ܂B]B
     *
     * @return tB[h[description]擾lB
     */
    public String getDescription() {
        return fDescription;
    }

    /**
     * tB[h [suffix] ̒lݒ肵܂B
     *
     * tB[h̐: [NX̌ɕt^TtBbNXB]B
     *
     * @param argSuffix tB[h[suffix]ɐݒ肷lB
     */
    public void setSuffix(final String argSuffix) {
        fSuffix = argSuffix;
    }

    /**
     * tB[h [suffix] ̒l擾܂B
     *
     * tB[h̐: [NX̌ɕt^TtBbNXB]B
     *
     * @return tB[h[suffix]擾lB
     */
    public String getSuffix() {
        return fSuffix;
    }

    /**
     * tB[h [forward] ̒lݒ肵܂B
     *
     * tB[h̐: [ʃtH[h̗LB]B
     *
     * @param argForward tB[h[forward]ɐݒ肷lB
     */
    public void setForward(final boolean argForward) {
        fForward = argForward;
    }

    /**
     * tB[h [forward] ̒l擾܂B
     *
     * tB[h̐: [ʃtH[h̗LB]B
     * ftHg: [false]B
     *
     * @return tB[h[forward]擾lB
     */
    public boolean getForward() {
        return fForward;
    }

    /**
     * tB[h [beanList] ̒lݒ肵܂B
     *
     * tB[h̐: [beanꗗ̃XgB]B
     *
     * @param argBeanList tB[h[beanList]ɐݒ肷lB
     */
    public void setBeanList(final List<blanco.jsf.valueobject.BlancoJsfBeanItemStructure> argBeanList) {
        fBeanList = argBeanList;
    }

    /**
     * tB[h [beanList] ̒l擾܂B
     *
     * tB[h̐: [beanꗗ̃XgB]B
     * ftHg: [new java.util.ArrayList<blanco.jsf.valueobject.BlancoJsfBeanItemStructure>()]B
     *
     * @return tB[h[beanList]擾lB
     */
    public List<blanco.jsf.valueobject.BlancoJsfBeanItemStructure> getBeanList() {
        return fBeanList;
    }

    /**
     * tB[h [sqlList] ̒lݒ肵܂B
     *
     * tB[h̐: [SQL`IDꗗ̃XgB]B
     *
     * @param argSqlList tB[h[sqlList]ɐݒ肷lB
     */
    public void setSqlList(final List<blanco.jsf.valueobject.BlancoJsfSqlItemStructure> argSqlList) {
        fSqlList = argSqlList;
    }

    /**
     * tB[h [sqlList] ̒l擾܂B
     *
     * tB[h̐: [SQL`IDꗗ̃XgB]B
     * ftHg: [new java.util.ArrayList<blanco.jsf.valueobject.BlancoJsfSqlItemStructure>();]B
     *
     * @return tB[h[sqlList]擾lB
     */
    public List<blanco.jsf.valueobject.BlancoJsfSqlItemStructure> getSqlList() {
        return fSqlList;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * <P>gp̒</P>
     * <UL>
     * <LI>IuWFNg̃V[͈͂̂ݕ񉻂̏ΏۂƂȂ܂B
     * <LI>IuWFNgzQƂĂꍇɂ́Ã\bh͎gȂłB
     * </UL>
     *
     * @return o[IuWFNg̕\B
     */
    @Override
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.jsf.valueobject.BlancoJsfStructure[");
        buf.append("name=" + fName);
        buf.append(",package=" + fPackage);
        buf.append(",description=" + fDescription);
        buf.append(",suffix=" + fSuffix);
        buf.append(",forward=" + fForward);
        buf.append(",beanList=" + fBeanList);
        buf.append(",sqlList=" + fSqlList);
        buf.append("]");
        return buf.toString();
    }
}

==> blanco.plugin.jsf_0.2.0-src.zip: src/blanco/jsf/valueobject/BlancoJsfStructure.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2009 IGA Tosiki
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.jsf.valueobject;

import java.util.List;

/**
 * blancoJsf ob`NX̊e킵܂B
 */
public class BlancoJsfStructure {
    /**
     * JSF̊IDw肵܂BK{ڂłBʏ͉IDƂȂ܂B
     *
     * tB[h: [name]B
     */
    private String fName;

    /**
     * pbP[Ww肵܂BK{ڂłB
     *
     * tB[h: [package]B
     */
    private String fPackage;

    /**
     * BeanB
     *
     * tB[h: [bean]B
     */
    private String fBean;

    /**
     * bZ[W`̐Lڂ܂B
     *
     * tB[h: [description]B
     */
    private String fDescription;

    /**
     * NX̌ɕt^TtBbNXB
     *
     * tB[h: [suffix]B
     */
    private String fSuffix;

    /**
     * JSF`̃XgB
     *
     * tB[h: [processList]B
     * ftHg: [new java.util.ArrayList<blanco.jsf.valueobject.BlancoJsfProcessStructure>();]B
     */
    private List<blanco.jsf.valueobject.BlancoJsfProcessStructure> fProcessList = new java.util.ArrayList<blanco.jsf.valueobject.BlancoJsfProcessStructure>();;

    /**
     * tB[h [name] ̒lݒ肵܂B
     *
     * tB[h̐: [JSF̊IDw肵܂BK{ڂłBʏ͉IDƂȂ܂B]B
     *
     * @param argName tB[h[name]ɐݒ肷lB
     */
    public void setName(final String argName) {
        fName = argName;
    }

    /**
     * tB[h [name] ̒l擾܂B
     *
     * tB[h̐: [JSF̊IDw肵܂BK{ڂłBʏ͉IDƂȂ܂B]B
     *
     * @return tB[h[name]擾lB
     */
    public String getName() {
        return fName;
    }

    /**
     * tB[h [package] ̒lݒ肵܂B
     *
     * tB[h̐: [pbP[Ww肵܂BK{ڂłB]B
     *
     * @param argPackage tB[h[package]ɐݒ肷lB
     */
    public void setPackage(final String argPackage) {
        fPackage = argPackage;
    }

    /**
     * tB[h [package] ̒l擾܂B
     *
     * tB[h̐: [pbP[Ww肵܂BK{ڂłB]B
     *
     * @return tB[h[package]擾lB
     */
    public String getPackage() {
        return fPackage;
    }

    /**
     * tB[h [bean] ̒lݒ肵܂B
     *
     * tB[h̐: [BeanB]B
     *
     * @param argBean tB[h[bean]ɐݒ肷lB
     */
    public void setBean(final String argBean) {
        fBean = argBean;
    }

    /**
     * tB[h [bean] ̒l擾܂B
     *
     * tB[h̐: [BeanB]B
     *
     * @return tB[h[bean]擾lB
     */
    public String getBean() {
        return fBean;
    }

    /**
     * tB[h [description] ̒lݒ肵܂B
     *
     * tB[h̐: [bZ[W`̐Lڂ܂B]B
     *
     * @param argDescription tB[h[description]ɐݒ肷lB
     */
    public void setDescription(final String argDescription) {
        fDescription = argDescription;
    }

    /**
     * tB[h [description] ̒l擾܂B
     *
     * tB[h̐: [bZ[W`̐Lڂ܂B]B
     *
     * @return tB[h[description]擾lB
     */
    public String getDescription() {
        return fDescription;
    }

    /**
     * tB[h [suffix] ̒lݒ肵܂B
     *
     * tB[h̐: [NX̌ɕt^TtBbNXB]B
     *
     * @param argSuffix tB[h[suffix]ɐݒ肷lB
     */
    public void setSuffix(final String argSuffix) {
        fSuffix = argSuffix;
    }

    /**
     * tB[h [suffix] ̒l擾܂B
     *
     * tB[h̐: [NX̌ɕt^TtBbNXB]B
     *
     * @return tB[h[suffix]擾lB
     */
    public String getSuffix() {
        return fSuffix;
    }

    /**
     * tB[h [processList] ̒lݒ肵܂B
     *
     * tB[h̐: [JSF`̃XgB]B
     *
     * @param argProcessList tB[h[processList]ɐݒ肷lB
     */
    public void setProcessList(final List<blanco.jsf.valueobject.BlancoJsfProcessStructure> argProcessList) {
        fProcessList = argProcessList;
    }

    /**
     * tB[h [processList] ̒l擾܂B
     *
     * tB[h̐: [JSF`̃XgB]B
     * ftHg: [new java.util.ArrayList<blanco.jsf.valueobject.BlancoJsfProcessStructure>();]B
     *
     * @return tB[h[processList]擾lB
     */
    public List<blanco.jsf.valueobject.BlancoJsfProcessStructure> getProcessList() {
        return fProcessList;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * <P>gp̒</P>
     * <UL>
     * <LI>IuWFNg̃V[͈͂̂ݕ񉻂̏ΏۂƂȂ܂B
     * <LI>IuWFNgzQƂĂꍇɂ́Ã\bh͎gȂłB
     * </UL>
     *
     * @return o[IuWFNg̕\B
     */
    @Override
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.jsf.valueobject.BlancoJsfStructure[");
        buf.append("name=" + fName);
        buf.append(",package=" + fPackage);
        buf.append(",bean=" + fBean);
        buf.append(",description=" + fDescription);
        buf.append(",suffix=" + fSuffix);
        buf.append(",processList=" + fProcessList);
        buf.append("]");
        return buf.toString();
    }
}
